@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "prescient" "6.3.2"
+(define-package "prescient" "20250816.19"
   "Better sorting and filtering."
   '((emacs "25.1"))
   :url "https://github.com/raxod502/prescient.el"
